<div class="col-6">
  <h5>Sketch Pad Input: (Use your cursor to draw)</h5>
  <canvas id="canvas" width="400" height="400"></canvas><br>
  <div class="btn-group" role="group" aria-label="Basic example">
  <button type="button" class="btn btn-primary" id="submit-button">Recognize</button>
  <button type="button" class="btn btn-secondary" id="clear-button">Clear</button>
  </div>
</div>

<script src="../js/sketchpad-input.js"></script>
