<div class="col-6">
  <h5>Textbox Input:</h5>
  <textarea id="textbox-input"></textarea>
  <div class="btn-group" role="group" aria-label="Basic example">
  <button type="button" class="btn btn-primary" id="submit-button">Submit</button>
  <button type="button" class="btn btn-secondary" id="clear-button">Clear</button>
  </div>
</div>

<script src="../js/textbox-input.js"></script>
