<!-- <link rel="stylesheet" href="../css/dropzone.css">
<div class="col-6">
	<h5>Image Upload Input:</h5>
	
<input type="file" onchange="previewFile()"><br>
<img src="" height="200" alt="Image preview...">

  <div class="btn-group" role="group" aria-label="Basic example">
  <button type="button" class="btn btn-primary" id="submit-button">Submit</button>
  <button type="button" class="btn btn-secondary" id="clear-button">Clear</button>
  </div>
</div>
<script src="../js/image-upload-input.js"></script>

 -->
<div class="col-6">
	<h5>Image Upload Input:</h5>

 <div class="uploader" onclick="$('#filePhoto').click()">
    click here or drag your images for preview
    <img src=""/>
    <input type="file" name="userprofile_picture"  id="filePhoto" />
</div>    
  <div class="btn-group" role="group" aria-label="Basic example">
  <button type="button" class="btn btn-primary" id="submit-button">Submit</button>
  <button type="button" class="btn btn-secondary" id="clear-button">Clear</button>
  </div>


</div>
<script src="../js/image-upload-input.js"></script>
